From 3a41012c114a1b2b98b648744f08488e48c8f037 Mon Sep 17 00:00:00 2001
From: Hayato Kuroda <kuroda.hayato@fujitsu.com>
Date: Mon, 14 Apr 2025 21:34:05 +0900
Subject: [PATCH v2 2/2] Follow naming rules for injection points

---
 src/backend/access/heap/heapam.c              |  2 +-
 src/backend/utils/cache/inval.c               |  2 +-
 .../expected/syscache-update-pruned.out       | 24 +++++++++----------
 .../expected/syscache-update-pruned_1.out     | 24 +++++++++----------
 .../specs/syscache-update-pruned.spec         | 12 +++++-----
 5 files changed, 32 insertions(+), 32 deletions(-)

diff --git a/src/backend/access/heap/heapam.c b/src/backend/access/heap/heapam.c
index ed2e3021799..0d01465d22e 100644
--- a/src/backend/access/heap/heapam.c
+++ b/src/backend/access/heap/heapam.c
@@ -3304,7 +3304,7 @@ heap_update(Relation relation, ItemPointer otid, HeapTuple newtup,
 	interesting_attrs = bms_add_members(interesting_attrs, id_attrs);
 
 	block = ItemPointerGetBlockNumber(otid);
-	INJECTION_POINT("heap_update-before-pin");
+	INJECTION_POINT("heap-update-before-pin");
 	buffer = ReadBuffer(relation, block);
 	page = BufferGetPage(buffer);
 
diff --git a/src/backend/utils/cache/inval.c b/src/backend/utils/cache/inval.c
index 4893dbdd7c8..d397a46663a 100644
--- a/src/backend/utils/cache/inval.c
+++ b/src/backend/utils/cache/inval.c
@@ -1200,7 +1200,7 @@ AtEOXact_Inval(bool isCommit)
 	/* Must be at top of stack */
 	Assert(transInvalInfo->my_level == 1 && transInvalInfo->parent == NULL);
 
-	INJECTION_POINT("AtEOXact_Inval-with-transInvalInfo");
+	INJECTION_POINT("inval-process-invalidation-messages");
 
 	if (isCommit)
 	{
diff --git a/src/test/modules/injection_points/expected/syscache-update-pruned.out b/src/test/modules/injection_points/expected/syscache-update-pruned.out
index 9a9683bb496..81b55c0314d 100644
--- a/src/test/modules/injection_points/expected/syscache-update-pruned.out
+++ b/src/test/modules/injection_points/expected/syscache-update-pruned.out
@@ -10,14 +10,14 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 ERROR:  tuple concurrently deleted
@@ -33,8 +33,8 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
@@ -42,8 +42,8 @@ step mkrels4:
 	SELECT FROM vactest.mkrels('intruder', 1, 100);  -- repopulate LP_UNUSED
 
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 ERROR:  duplicate key value violates unique constraint "pg_class_oid_index"
@@ -64,15 +64,15 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
 step at4: ALTER TABLE vactest.child50 INHERIT vactest.orig50;
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 step wakegrant4: <... completed>
diff --git a/src/test/modules/injection_points/expected/syscache-update-pruned_1.out b/src/test/modules/injection_points/expected/syscache-update-pruned_1.out
index 64c39d708bd..dd1519e95da 100644
--- a/src/test/modules/injection_points/expected/syscache-update-pruned_1.out
+++ b/src/test/modules/injection_points/expected/syscache-update-pruned_1.out
@@ -10,14 +10,14 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 step wakegrant4: <... completed>
@@ -32,8 +32,8 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
@@ -41,8 +41,8 @@ step mkrels4:
 	SELECT FROM vactest.mkrels('intruder', 1, 100);  -- repopulate LP_UNUSED
 
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 step wakegrant4: <... completed>
@@ -62,15 +62,15 @@ step waitprunable4: CALL vactest.wait_prunable();
 step vac4: VACUUM (FREEZE, DISABLE_PAGE_SKIPPING) pg_class;
 step grant1: GRANT SELECT ON vactest.orig50 TO PUBLIC; <waiting ...>
 step wakeinval4: 
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
  <waiting ...>
 step at2: <... completed>
 step wakeinval4: <... completed>
 step at4: ALTER TABLE vactest.child50 INHERIT vactest.orig50;
 step wakegrant4: 
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
  <waiting ...>
 step grant1: <... completed>
 ERROR:  tuple concurrently updated
diff --git a/src/test/modules/injection_points/specs/syscache-update-pruned.spec b/src/test/modules/injection_points/specs/syscache-update-pruned.spec
index 086d084de25..6308bba8134 100644
--- a/src/test/modules/injection_points/specs/syscache-update-pruned.spec
+++ b/src/test/modules/injection_points/specs/syscache-update-pruned.spec
@@ -103,7 +103,7 @@ session s1
 setup	{
 	SET debug_discard_caches = 0;
 	SELECT FROM injection_points_set_local();
-	SELECT FROM injection_points_attach('heap_update-before-pin', 'wait');
+	SELECT FROM injection_points_attach('heap-update-before-pin', 'wait');
 }
 step cachefill1	{ SELECT FROM vactest.reloid_catcache_set('vactest.orig50'); }
 step grant1	{ GRANT SELECT ON vactest.orig50 TO PUBLIC; }
@@ -117,7 +117,7 @@ session s2
 setup	{
 	SELECT FROM injection_points_set_local();
 	SELECT FROM
-		injection_points_attach('AtEOXact_Inval-with-transInvalInfo', 'wait');
+		injection_points_attach('inval-process-invalidation-messages', 'wait');
 }
 step at2	{
 	CREATE TRIGGER to_set_relhastriggers BEFORE UPDATE ON vactest.orig50
@@ -140,13 +140,13 @@ step mkrels4	{
 	SELECT FROM vactest.mkrels('intruder', 1, 100);  -- repopulate LP_UNUSED
 }
 step wakegrant4	{
-	SELECT FROM injection_points_detach('heap_update-before-pin');
-	SELECT FROM injection_points_wakeup('heap_update-before-pin');
+	SELECT FROM injection_points_detach('heap-update-before-pin');
+	SELECT FROM injection_points_wakeup('heap-update-before-pin');
 }
 step at4	{ ALTER TABLE vactest.child50 INHERIT vactest.orig50; }
 step wakeinval4	{
-	SELECT FROM injection_points_detach('AtEOXact_Inval-with-transInvalInfo');
-	SELECT FROM injection_points_wakeup('AtEOXact_Inval-with-transInvalInfo');
+	SELECT FROM injection_points_detach('inval-process-invalidation-messages');
+	SELECT FROM injection_points_wakeup('inval-process-invalidation-messages');
 }
 # Witness effects of steps at2 and/or at4.
 step inspect4	{
-- 
2.43.5

